<?php
// wcf imports
require_once(WCF_DIR.'lib/data/user/notification/Notification.class.php');

/**
 * Extends the notification object with functions to create, update and delete notifications
 *
 * @author	Oliver Kliebisch
 * @copyright	2009-2010 Oliver Kliebisch
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.community.wcf.user.notification
 * @subpackage	data.user.notification
 * @category 	Community Framework
 */
class NotificationEditor extends Notification {
        /**
         * Creates a new notification in the database
         *
         * @param       integer         $userID
         * @param       string          $objectType
         * @param       integer         $objectID
         * @param       string          $eventName
         * @param       integer         $time
         * @param       string          $shortOutput
         * @param       string          $mediumOutput
         * @param       string          $longOutput
         * @param       integer         $confirmed
         * @param       array<mixed>    $additionalData
         * @param       array<mixed>    $additionalFields
         * @return      NotificationEditor
         */
        public static function create($userID, $packageID, $objectType, $objectID, $eventName, $time = TIME_NOW, $shortOutput = '', $mediumOutput = '', $longOutput = '', $confirmed = 0, $confirmationTime = 0, $additionalData = array(), $additionalFields = array()) {
                // save data
                $notificationID = self::insert($userID, array_merge($additionalFields, array(
                        'packageID' => $packageID,
                        'objectType' => $objectType,
                        'objectID' => $objectID,
                        'eventName' => $eventName,
                        'time' => $time,
                        'shortOutput' => $shortOutput,
                        'mediumOutput' => $mediumOutput,
                        'longOutput' => $longOutput,
                        'confirmed' => $confirmed,
                        'confirmationTime' => $confirmationTime,
                        'additionalData' => serialize($additionalData)
                )));

                // get notification
                $notification = new NotificationEditor($notificationID);

                return $notification;
        }

        /**
	 * Creates the notification row in database table.
	 *
	 * @param 	integer 	$userID
	 * @param 	array		$additionalFields
	 * @return	integer		new notification id
	 */
	public static function insert($userID, $additionalFields = array()) {
		$keys = $values = '';
		foreach ($additionalFields as $key => $value) {
			$keys .= ','.$key;
			if (is_int($value)) $values .= ",".$value;
			else $values .= ",'".escapeString($value)."'";
		}

		$sql = "INSERT INTO	wcf".WCF_N."_user_notification
					(userID
					".$keys.")
			VALUES		(".$userID."
					".$values.")";
		WCF::getDB()->sendQuery($sql);
                
		return WCF::getDB()->getInsertID();
	}

        /**
         * Updates the notification
         * 
         * @param       integer         $userID
         * @param       string          $objectType
         * @param       integer         $objectID
         * @param       string          $eventName
         * @param       integer         $time
         * @param       string          $shortOutput
         * @param       string          $mediumOutput
         * @param       string          $longOutput
         * @param       integer         $confirmed
         * @param       integer         $confirmationTime
         * @param       array<mixed>    $additionalData
         * @param       array<mixed>    $additionalFields
         */
        public static function update($userID = null, $packageID = null, $objectType = null, $objectID = null, $eventName = null, $time = null, $shortOutput = null, $mediumOutput = null, $longOutput = null, $confirmed = null, $confirmationTime = null, $additionalData = null, $additionalFields = array()) {
                $fields = array();
                if ($userID !== null) $fields['userID'] = $userID;
                if ($packageID !== null) $fields['packageID'] = $packageID;
                if ($objectType !== null) $fields['objectType'] = $objectType;
                if ($objectID !== null) $fields['objectID'] = $objectID;
                if ($eventName !== null) $fields['eventName'] = $eventName;
                if ($time !== null) $fields['time'] = $time;
                if ($shortOutput !== null) $fields['shortOutput'] = $shortOutput;
                if ($mediumOutput !== null) $fields['mediumOutput'] = $mediumOutput;
                if ($longOutput !== null) $fields['longOutput'] = $longOutput;
                if ($confirmed !== null) $fields['confirmed'] = $confirmed;
                if ($confirmationTime !== null) $fields['confirmationTime'] = $confirmationTime;
                if ($additionalData !== null) $fields['additionalData'] = serialize($additionalData);

                $this->updateData(array_merge($fields, $additionalFields));
        }

        /**
	 * Updates the data of a notification
	 *
	 * @param 	array		$fields
	 */
	public function updateData($fields = array()) {
		$updates = '';
		foreach ($fields as $key => $value) {
			if (!empty($updates)) $updates .= ',';
			$updates .= $key.'=';
			if (is_int($value)) $updates .= $value;
			else $updates .= "'".escapeString($value)."'";
		}

		if (!empty($updates)) {
			$sql = "UPDATE	wcf".WCF_N."_user_notification
				SET	".$updates."
				WHERE	notificationID = ".$this->notificationID;
			WCF::getDB()->sendQuery($sql);
		}
	}

        /**
         * Adds a notification type message to the notifcation
         *
         * @param       string          $notificationType
         * @param       string          $message
         */
        public function addMessage($notificationType, $transportID = 0, $message = '') {
                $sql = "INSERT INTO             wcf".WCF_N."_user_notification_message
                                                (notificationID, transportID, notificationType, messageCache)
                        VALUES                  (".$this->notificationID.",
                                                ".$transportID.",
                                                '".escapeString($notificationType)."',
                                                '".escapeString($message)."')
                        ON DUPLICATE KEY UPDATE messageCache = VALUES(messageCache)";
                WCF::getDB()->sendQuery($sql);
        }

        /**
         * Marks this notification as confirmed
         */
        public function markConfirmed() {
                self::markAllConfirmed(array($this->notificationID));
        }

        /**
         * Marks all given notifications as confirmed
         * 
         * @param       array<integer>          $notificationIDArray         
         */
        public static function markAllConfirmed($notificationIDArray = array()) {
                if (!count($notificationIDArray)) return;

                $sql = "UPDATE          wcf".WCF_N."_user_notification
                        SET             confirmed = 1,
                                        confirmationTime = ".TIME_NOW."
                        WHERE           notificationID IN (".implode(',', $notificationIDArray).")";
                WCF::getDB()->sendQuery($sql);
        }

        /**
         * Marks all notifications related to the current view scope of the given user as confirmed
         * Returns the count of affected notifications
         *
         * @param       integer         $userID
         * @param       array<string>   $eventNameArray
         * @param       string          $objectType
         * @param       array<integer>  $objectIDArray
         * @return      integer
         */
        public static function markConfirmedByObjectVisit($userID, $eventNameArray = array(), $objectType = null, $objectIDArray = array()) {
                if (!count($eventNameArray) || !count($objectIDArray) || !$objectType) return;

                $objectTypeObject = NotificationHandler::getNotificationObjectTypeObject($objectType);

                $sql = "UPDATE          wcf".WCF_N."_user_notification
                        SET             confirmed = 1,
                                        confirmationTime = ".TIME_NOW."
                        WHERE           userID = ".$userID."
                        AND             eventName IN('".implode("','", array_map('escapeString', $eventNameArray))."')
                        AND             objectType = '".escapeString($objectType)."'
                        AND             objectID IN(".implode(',', $objectIDArray).")
                        AND             packageID = ".$objectTypeObject->getPackageID();
                WCF::getDB()->sendQuery($sql);

                return WCF::getDB()->getAffectedRows();
        }

        /**
         * Deletes this notification
         */
        public function delete() {
                self::deleteAll(array($this->notificationID));
        }

        /**
         * Deletes all given notifications
         *
         * @param       array<integer>         $notificationIDArray
         */
        public static function deleteAll($notificationIDArray = array()) {
                if (!count($notificationIDArray)) return;

                // delete data
                $sql = "DELETE FROM     wcf".WCF_N."_user_notification
                        WHERE           notificationID IN (".implode(',', $notificationIDArray).")";
                WCF::getDB()->sendQuery($sql);

                $sql = "DELETE FROM     wcf".WCF_N."_user_notification_message
                        WHERE           notificationID IN (".implode(',', $notificationIDArray).")";
                WCF::getDB()->sendQuery($sql);
        }

        /**
         * Returns notifications based on the given parameters
         * 
         * @param       integer         $objectID
         * @param       string          $objectType
         * @param       string          $eventName
         * @param       integer         $userID
         * @param       integer         $confirmed
         * @return      array<NotificationEditor>
         */
        public static function getNotificationsByObject($objectID, $objectType, $eventName = null, $userID = null, $confirmed = null) {
                $objectTypeObject = NotificationHandler::getNotificationObjectTypeObject($objectType);

                $sql = "SELECT  *
                        FROM    wcf".WCF_N."_user_notification
                        WHERE   objectID = ".$objectID."
                        AND     objectType = '".escapeString($objectType)."'
                        AND     packageID = ".$objectTypeObject->getPackageID()."
                        ".($eventName ? " AND    eventName = '".escapeString($eventName)."'" : "")."
                        ".($userID !== null ? " AND      userID = ".$userID : "")."
                        ".($confirmed !== null ? " AND      confirmed = ".$confirmed : "");
                $result = WCF::getDB()->sendQuery($sql);

                $notifications = array();
                while ($row = WCF::getDB()->fetchArray($result)) {
                        $notifications[] = new NotificationEditor(null, $row);
                }

                return $notifications;
        }
}
?>