<?php
// wcf import
require_once(WCF_DIR.'lib/data/DatabaseObject.class.php');
require_once(WCF_DIR.'lib/data/user/notification/event/NotificationEvent.class.php');
require_once(WCF_DIR.'lib/data/user/notification/object/NotificationObject.class.php');

/**
 * This is an abstract implementation of the NotificationEvent
 *
 * @author	Oliver Kliebisch
 * @copyright	2009-2010 Oliver Kliebisch
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.community.wcf.user.notification
 * @subpackage	data.user.notification.event
 * @category 	Community Framework
 */
abstract class AbstractNotificationEvent extends DatabaseObject implements NotificationEvent {
        /**
         * The language object of the recipient user's language
         *
         * @var Language
         */
        protected $language = null;

        /**
         * The notification object
         *
         * @var NotificationObject
         */
        protected $object = null;

        /**
         * Additional data for this event
         *
         * @var array<mixed>
         */
        public $additionalData = array();

        /**
         * @see NotificationEvent::initialize()
         */
        public function initialize(&$data) {
                return;
        }

        /**
         * @see NotificationEvent::getMessage()
         */
        public function getMessage(NotificationType $notificationType, $additionalVariables = array()) {
                return $this->getLanguageVariable($this->languageCategory.'.'.$this->getEventName().'.'.$notificationType->getName(), $additionalVariables);
        }

        /**
         * @see NotificationEvent::getShortOutput()
         */
        public function getShortOutput() {
                 return $this->getLanguageVariable($this->languageCategory.'.'.$this->getEventName().'.short');
        }

        /**
         * @see NotificationEvent::getMediumOutput()
         */
        public function getMediumOutput() {
                 return $this->getLanguageVariable($this->languageCategory.'.'.$this->getEventName().'.medium');
        }

        /**
         * @see NotificationEvent::getShortOutput()
         */
        public function getOutput() {
                return $this->getLanguageVariable($this->languageCategory.'.'.$this->getEventName());
        }

        /**
         * @see NotificationEvent::getTitle()
         */
        public function getTitle() {
                 return $this->getLanguageVariable($this->languageCategory.'.'.$this->getEventName().'.title');
        }

        /**
         * @see NotificationEvent::getTitle()
         */
        public function getDescription() {
                 return $this->getLanguageVariable($this->languageCategory.'.'.$this->getEventName().'.description');
        }

        /**
         * @see NotificationEvent::getLanguageVariable()
         */
        public function getLanguageVariable($var, $additionalVariables = array()) {
                return $this->getLanguage()->getDynamicVariable($var, array_merge($additionalVariables,
                         array(
                                'event' => $this
                         )
                 ));
        }

        /**
         * @see NotificationEvent::supportsNotificationType()
         */
        public function supportsNotificationType(NotificationType $notificationType) {
               // returns true if the language variable exists. By using the
               // static getter, errors are avoided
               return ($this->getLanguage()->get($this->languageCategory.'.'.$this->getEventName().'.'.$notificationType->getName()) != $this->languageCategory.'.'.$this->getEventName().'.'.$notificationType->getName());
        }

        /**
         * @see NotificationEvent::getLanguage()
         */
        public function getLanguage() {
                if ($this->language === null || !$this->language instanceof Language) {
                        $this->language = WCF::getLanguage();
                }

                return $this->language;
        }

        /**
         * @see NotificationEvent::setLanguage()
         */
        public function setLanguage(Language $language) {
                $this->language = $language;
        }

        /**
         * @see NotificationEvent::getObject()
         */
        public function getObject() {
                return $this->object;
        }

        /**
         * @see NotificationEvent::setObject()
         */
        public function setObject(NotificationObject $object, $additionalData = array()) {
                $this->object = $object;
                $this->additionalData = $additionalData;
        }

        /**
         * @see NotificationEvent::getEventName()
         */
        public function getEventName() {
                return $this->eventName;
        }

        /**
         * @see NotificationEvent::getIcon()
         */
        public function getIcon() {
                return $this->icon;
        }

        /**
         * @see NotificationEvent::getAcceptURL()
         */
        public function getAcceptURL(Notification $notification) {
                if ($this->requiresConfirmation) {
                        if ($this->acceptURL) {
                                return $this->parseURL($this->acceptURL, $notification);
                        }
                        else return $this->parseURL('index.php?action=NotificationConfirm&notificationID='.$notification->notificationID, $notification);
                }
                else return '';
        }

        /**
         * @see NotificationEvent::getDeclineURL()
         */
        public function getDeclineURL(Notification $notification) {
                if ($this->requiresConfirmation && $this->declineURL) {
                        return $this->parseURL($this->declineURL, $notification);
                }
                else return '';
        }

        /**
         * Parses accept and decline URLs
         *
         * @param       string          $url
         * @param       Notification    $notification
         * @return      string
         */
        protected function parseURL($url, Notification $notification) {
                $url = str_replace('%u', $notification->userID, $url);
                $url = str_replace('%o', $notification->objectID, $url);
                $url = str_replace('%n', $notification->notificationID, $url);

                // append request uri
                if (WCF::getSession()->requestMethod == 'GET') {
                        if (StringUtil::indexOf($url, '?') !== false) {
                                $url .= '&';
                        }
                        else $url .= '?';
                        preg_match('/index\.php.*/is', WCF::getSession()->requestURI, $requestURI);

                        $url .= 'url='.rawurlencode($requestURI[0]);
                }

                // append security token
                $url .= '&t='.SECURITY_TOKEN;

                // append session id
                if (SID_ARG_1ST != '' && !preg_match('/(?:&|\?)s=[a-z0-9]{40}/', $url)) {
			if (StringUtil::indexOf($url, '?') !== false) $url .= SID_ARG_2ND_NOT_ENCODED;
			else $url .= SID_ARG_1ST;
		}

                return $url;
        }
}
?>