<?php
// wcf imports
require_once(WCF_DIR.'lib/data/user/notification/object/NotificationObject.class.php');

/**
 * This interface defines the basic methods every notification object type should implement.
 *
 * @author	Oliver Kliebisch
 * @copyright	2009-2010 Oliver Kliebisch
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.community.wcf.user.notification
 * @subpackage	data.user.notification.object
 * @category 	Community Framework
 */
interface NotificationObjectType {
        /**
	 * Get the notification object by its ID
	 *
	 * @param	integer		$objectID
	 * @return      NotificationObject
	 */
	public function getObjectByID($objectID);

        /**
	 * Get the notification object by using its parent object
	 *
	 * @param	object  	$object
	 * @return	NotificationObject
	 */
	public function getObjectByObject($object);

        /**
	 * Get the notification objects by their IDs
	 *
	 * @param	array<integer>		$objectIDArray
	 * @return	array<NotificationObject>
	 */
	public function getObjectsByIDArray($objectIDArray);

        /**
	 * Get the notification objects
	 *
	 * @param	mixed		$data
	 * @return	array<NotificationObject>
	 */
	public function getObjects($data);

	/**
	 * Returns the package ID of the object's package
	 * It does not return the package ID of the oject type package
	 *
	 * @return integer
	 */
	public function getPackageID();

	/**
	 * Returns additional packageIDs.
	 * This can be used for multiple combined dependency trees
	 *
	 * @return array<integer>
	 */
	public function getAdditionalPackageIDs();
}
?>
