<?php
// wcf imports
require_once(WCF_DIR.'lib/data/user/notification/type/NotificationType.class.php');

/**
 * A notification type for sending mail notifications
 *
 * @author	Oliver Kliebisch
 * @copyright	2009-2010 Oliver Kliebisch
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.community.wcf.user.notification
 * @subpackage	data.user.notification.type
 * @category 	Community Framework
 */
class MailNotificationType implements NotificationType {        
        /**
         * @see NotificationType::send()
         */
        public function send(User $user, NotificationEvent $event, NotificationEditor $notification) {
                // get messages
                $message = $event->getMessage($this, array(
                                'user' => $user,
                                'pageURL' => FileUtil::addTrailingSlash(PAGE_URL)
                ));

                // append notification mail footer
                $token = $user->notificationMailToken;
                if (!$token) {
                        // generate token if not present
                        $token = StringUtil::substring($token = StringUtil::getHash(serialize(array($user->userID, StringUtil::getRandomID()))), 0, 20);
                        $editor = $user->getEditor();
                        $editor->updateOptions(array('notificationMailToken' => $token));
                }
                $message .= "\n".$event->getLanguage()->getDynamicVariable('wcf.user.notification.type.mail.footer',  array(
                                'user' => $user,
                                'pageURL' => FileUtil::addTrailingSlash(PAGE_URL),
                                'token' => $token,
                                'notification' => $notification
                ));

                // Use short output as mail subject and strip its HTML
                $shortMessage = StringUtil::stripHTML($notification->shortOutput);

                // build mail
		require_once(WCF_DIR.'lib/data/mail/Mail.class.php');
		$mail = new Mail(array($user->username => $user->email), $event->getLanguageVariable('wcf.user.notification.type.mail.subject', array('title' => $shortMessage)), $message);

                $mail->send();
        }

        /**
         * @see NotificationType::revoke()
         */
        public function revoke(User $user, NotificationEvent $event, NotificationEditor $notification) {
                // unsupported
                return;
        }

        /**
         * @see NotificationType::getName()
         */
        public function getName() {
                return 'mail';
        }

        /**
         * @see NotificationType::getIcon()
         */
        public function getIcon() {
                return 'email';
        }
}
?>
