<?php
// wcf imports
require_once(WCF_DIR.'lib/data/user/User.class.php');
require_once(WCF_DIR.'lib/data/user/notification/event/NotificationEvent.class.php');
require_once(WCF_DIR.'lib/data/user/notification/NotificationEditor.class.php');

/**
 * This interface should be implemented by every notification type
 *
 * @author	Oliver Kliebisch
 * @copyright	2009-2010 Oliver Kliebisch
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	com.woltlab.community.wcf.user.notification
 * @subpackage	data.user.notification.type
 * @category 	Community Framework
 */
interface NotificationType {
        /**
         * Sends the notification using this notification transport type
         *
         * @param       User                    $user
         * @param       NotificationEvent       $event
         * @param       NotificationEditor      $notification
         */
        public function send(User $user, NotificationEvent $event, NotificationEditor $notification);

        /**
         * Tries to revoke the notification. This might not be applicable for
         * all notification types
         *
         * @param       User                    $user
         * @param       NotificationEvent       $event
         * @param       NotificationEditor      $notification
         */
        public function revoke(User $user, NotificationEvent $event, NotificationEditor $notification);

        /**
         * Returns the name of the notification type
         *
         * @return string
         */
        public function getName();

        /**
         * Returns the icon of the notification type
         *
         * @return string
         */
        public function getIcon();
}
?>
